# _ __ ___   ___ _ __ __ _  ___    ___ ___  _ __ ___     ___ ___ | |
#| '_ ` _ \ / _ \ '__/ _` |/ _ \  / __/ _ \| '_ ` _ \   / __/ _ \| |
#| | | | | |  __/ | | (_| |  __/ | (_| (_) | | | | | | | (_| (_) | |
#|_| |_| |_|\___|_|  \__, |\___|  \___\___/|_| |_| |_|  \___\___/|_|
#                    |___/                                          
#
# Merge two data sets based on their common column names
# Christopher Cole
# especially useful for merging plink2r output for multiple cohorts.


merge_com_col <- function(Table_A,Table_B,sep = " ", h = T, write = FALSE, out.name = NA) {

	if (typeof(Table_A) == "character") {
	A <- read.table(Table_A, sep = sep, h = h)
	} else if (typeof(Table_A) == "list") {
	A <- Table_A
	} else {	
	stop("Invalid input, please use either a data.frame or a text string naming the file")
	}
	
	if (typeof(Table_B) == "character") {
	B <- read.table(Table_B, sep = sep, h = h)
	} else if (typeof(Table_B) == "list") {
	B <- Table_B
	} else {	
	stop("Invalid input, please use either a data.frame or a text string naming the file")
	}
	
	common <- intersect(names(A),names(B))
	
	Output <- rbind(A[,common], B[,common])
	
	if (write == TRUE) {
	
	write.table(Output, out.name, sep = sep, h = h)
	
	}
	
	return(Output)
}
